@@ -1,8 +1,8 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
 
 """main: a wrapper for the pandoc-fignos/eqnos/tablenos/secnos filters."""
 
-# Copyright 2015-2019 Thomas J. Duck.
+# Copyright 2015-2020 Thomas J. Duck.
 # All rights reserved.
 #
 # This program is free software: you can redistribute it and/or modify
@@ -42,3 +42,6 @@ def main():
             pass
     STDOUT.write(stdin.read())
     STDOUT.flush()
+
+if __name__ == '__main__':
+    main()
